/*  Gtk+ Widget Factory
 *  Copyright (C) 1999-2000  Jeroen Benckhuijsen
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <gtk/gtk.h>
#include "gwf_projtreebasic.h"
#include "gwf_projlist.h"
#include "gwf_project.h"
#include "gwf_treedata.h"
#include "gwf_tools.h"

enum
{
	AUTHOR,
	EMAIL,
	FILENAME,
	CFILE,
	HFILE,
	PRNTNAME,
	PRNTINCL,
	BACKUP,
	EXAMPLE,
	LICENSE,
	WIDGETTYPE,
	
	LAST_NODE
};

static GwfPTData		basic_pt_data[LAST_NODE] =
  {
    {NULL,	"Author",		NULL,	"author_changed",	0,	gwf_projtree_node_string_changed_cb,	NULL, NULL},
    {NULL,	"Email",		NULL,	"email_changed",	0,	gwf_projtree_node_string_changed_cb,	NULL, NULL},
    {NULL,	"Filename",		NULL,	"filename_changed",	0,	gwf_projtree_node_string_changed_cb,	NULL, NULL},
    {NULL,	"C file",		NULL,	"cfile_changed",	0,	gwf_projtree_node_string_changed_cb,	NULL, NULL},
    {NULL,	"H file",		NULL,	"hfile_changed",	0,	gwf_projtree_node_string_changed_cb,	NULL, NULL},
    {NULL,	"Parent name",		NULL,	"prntname_changed",	0,	gwf_projtree_node_string_changed_cb,	NULL, NULL},
    {NULL,	"Parent include file",	NULL,	"prntincl_changed",	0,	gwf_projtree_node_string_changed_cb,	NULL, NULL},
    {NULL,	"Backup source files",	NULL,	"backup_changed",	0,	gwf_projtree_node_bool_changed_cb,	NULL, NULL},
    {NULL,	"Generate example",	NULL,	"example_changed",	0,	gwf_projtree_node_bool_changed_cb,	NULL, NULL},
    {NULL,	"License",		NULL,	"license_changed",	0,	gwf_projtree_node_string_changed_cb,	NULL, NULL},
    {NULL,	"Widget type",		NULL,	"widget_type_changed",	0,	gwf_projtree_node_string_changed_cb,	NULL, NULL}
  };

void
gwf_projtree_basic_attach (GwfTreeData *data,GwfProject *project)
{
  GwfPTData	**pt_data;

  g_return_if_fail(data != NULL);
  g_return_if_fail(project != NULL);
  g_return_if_fail(data->tree != NULL);

  pt_data = gwf_projtree_add_new_section(data,project,"Basic",basic_pt_data,LAST_NODE);
  if (!pt_data)
    return;

  gwf_projtree_insert_string_by_ptdata(pt_data[AUTHOR],gwf_project_get_author(project));
  gwf_projtree_insert_string_by_ptdata(pt_data[EMAIL],gwf_project_get_email(project));
  gwf_projtree_insert_string_by_ptdata(pt_data[PRNTNAME],gwf_project_get_prntname(project));
  gwf_projtree_insert_string_by_ptdata(pt_data[PRNTINCL],gwf_project_get_prntincl(project));
  gwf_projtree_insert_string_by_ptdata(pt_data[WIDGETTYPE],gwf_project_get_widget_type(project));
  gwf_projtree_insert_string_by_ptdata(pt_data[FILENAME],gwf_project_get_filename(project));
  gwf_projtree_insert_string_by_ptdata(pt_data[CFILE],gwf_project_get_cfile(project));
  gwf_projtree_insert_string_by_ptdata(pt_data[HFILE],gwf_project_get_hfile(project));
  gwf_projtree_insert_string_by_ptdata(pt_data[LICENSE],gwf_project_get_license(project));
  gwf_projtree_insert_bool_by_ptdata(pt_data[BACKUP],gwf_project_get_backup(project));
  gwf_projtree_insert_bool_by_ptdata(pt_data[EXAMPLE],gwf_project_get_example(project));
}
