/*  Gtk+ Widget Factory
 *  Copyright (C) 1999-2000  Jeroen Benckhuijsen
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include "gwf_xmlio_basic.h"
#include "gwf_xmlio.h"
#include "gwf_error.h"
#include "gwf_project.h"
#include "gwf_tools.h"
#include <gtk/gtk.h>

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

enum
{
   GWF_WIDNAME,
   GWF_AUTHOR,
   GWF_EMAIL,
   GWF_CFILE,
   GWF_HFILE,
   GWF_BACKUP,
   GWF_LICENSE,
   GWF_PRNTNAME,
   GWF_PRNTINCL,
   GWF_EXAMPLE,
   GWF_WIDGETTYPE,

   LAST_BASIC_TAG
};

static gchar		*xml_tags[LAST_BASIC_TAG] = 	{
							"WIDNAME",
                                                        "AUTHOR",
                                                        "EMAIL",
							"CFILE",
							"HFILE",
							"BACKUP",
                                                        "LICENSE",
                                                        "PRNTNAME",
                                                        "PRNTINCL",
                                                        "EXAMPLE",
                                                        "WIDGETYPE"
							};

enum
{
   GWF_PRNTCLASS, /* Version 0.1.0 */
   GWF_FORMAT, /* Version 0.2.0 */
   GWF_PRNTCHECK, /* Version 0.3.0 */
   GWF_TYPECHECK, /* Version 0.3.0 */

   LAST_OLD_TAG
};							

static gchar		*old_xml_tags [LAST_OLD_TAG] =  {
							"PRNTCLASS" /* Version 0.1.0 */
							"FORMAT", /* Version 0.2.0 */
                                                        "PARENTCHECK", /* Version 0.3.0 */
                                                        "TYPEHECK" /* Version 0.3.0 */
							};

static gint		handle_old_tags		(xmlNodePtr cur,xmlNsPtr ns,GwfXmlIO *xml_io,GwfProject *project);

gint
gwf_xmlio_load_basic(xmlNodePtr cur,xmlNsPtr ns,GwfXmlIO *xml_io,GwfProject *project,GwfError *error)
{
  gint 		ok = 1;
  gchar		*tmp;

  g_return_val_if_fail(cur != NULL,0);
  g_return_val_if_fail(xml_io != NULL,0);
  g_return_val_if_fail(project != NULL,0);

  while (cur && ok)
  {
    if ((strcmp(cur->name,xml_tags[GWF_WIDNAME]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_widname(project,tmp);
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_AUTHOR]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_author(project,tmp);
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_EMAIL]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_email(project,tmp);
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_CFILE]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_cfile(project,tmp);
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_HFILE]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_hfile(project,tmp);
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_BACKUP]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_backup(project,STR_TO_BOOL(tmp));
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_LICENSE]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_license(project,tmp);
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_PRNTNAME]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_prntname(project,tmp);
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_PRNTINCL]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_prntincl(project,tmp);
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_EXAMPLE]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_example(project,STR_TO_BOOL(tmp));
      g_free(tmp);
    }
    else
    if ((strcmp(cur->name,xml_tags[GWF_WIDGETTYPE]) == 0) && (cur->ns == ns))
    {
      tmp = xmlNodeGetContent(cur);
      gwf_project_set_widget_type(project,tmp);
      g_free(tmp);
    }
    else
    if (!handle_old_tags(cur,ns,xml_io,project)) /* For compatibility with older versions */
    {
      gwf_error_raise_error(error,"XmlIO : Unknown tag",cur->name);
      ok = 0;
    }

    cur = cur->next;
  }

  return ok;
}

gint
gwf_xmlio_save_basic(xmlNodePtr parent,xmlNsPtr ns,GwfProject *project)
{
  g_return_val_if_fail(parent != NULL,0);
  g_return_val_if_fail(project != NULL,0);

  xmlNewChild(parent,ns,xml_tags[GWF_WIDNAME],gwf_project_get_widname(project));

  if (gwf_project_get_author(project))
    xmlNewChild(parent,ns,xml_tags[GWF_AUTHOR],gwf_project_get_author(project));

  if (gwf_project_get_email(project))
    xmlNewChild(parent,ns,xml_tags[GWF_EMAIL],gwf_project_get_email(project));

  if (gwf_project_get_cfile(project))
    xmlNewChild(parent,ns,xml_tags[GWF_CFILE],gwf_project_get_cfile(project));

  if (gwf_project_get_hfile(project))
    xmlNewChild(parent,ns,xml_tags[GWF_HFILE],gwf_project_get_hfile(project));

  if (gwf_project_get_license(project))
    xmlNewChild(parent,ns,xml_tags[GWF_LICENSE],gwf_project_get_license(project));

  if (gwf_project_get_prntname(project))
    xmlNewChild(parent,ns,xml_tags[GWF_PRNTNAME],gwf_project_get_prntname(project));

  if (gwf_project_get_prntincl(project))
    xmlNewChild(parent,ns,xml_tags[GWF_PRNTINCL],gwf_project_get_prntincl(project));

  if (gwf_project_get_widget_type(project))
    xmlNewChild(parent,ns,xml_tags[GWF_WIDGETTYPE],gwf_project_get_widget_type(project));

  xmlNewChild(parent,ns,xml_tags[GWF_BACKUP],BOOL_TO_STR(gwf_project_get_backup(project)));
  xmlNewChild(parent,ns,xml_tags[GWF_EXAMPLE],BOOL_TO_STR(gwf_project_get_example(project)));

  return 1;
}

static gint
handle_old_tags(xmlNodePtr cur,xmlNsPtr ns,GwfXmlIO *xml_io,GwfProject *project)
{
  return ( (cur->ns == ns) &&
           ( (strcmp(cur->name,old_xml_tags[GWF_PRNTCLASS]) == 0) ||	/* For compatibility with version 0.1.0 */
             (strcmp(cur->name,old_xml_tags[GWF_FORMAT]) == 0) ||	/* For compatibility with version 0.2.0 */
             (strcmp(cur->name,old_xml_tags[GWF_PRNTCHECK]) == 0) ||	/* For compatibility with version 0.3.0 */
             (strcmp(cur->name,old_xml_tags[GWF_TYPECHECK]) == 0)	/* For compatibility with version 0.3.0 */
           )
         );
}
